-- ----------------------------
-- 学习项目表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_project`;
CREATE TABLE mortals_xhx_project(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键ID，主键，自增长',
    `title` varchar(256) NOT NULL     COMMENT '标题',
    `projectType` tinyint(2)    DEFAULT '0'  COMMENT '项目类型(0.法律法规,1.业务知识,2.行业知识,3.通用知识)',
    `projectStartTime` datetime NOT NULL     COMMENT '开始时间',
    `projectEndTime` datetime NOT NULL     COMMENT '结束时间',
    `top` tinyint(2) NOT NULL   DEFAULT '0'  COMMENT '是否置顶(0.否，1.是)',
    `readRequest` tinyint(2) NOT NULL   DEFAULT '0'  COMMENT '已读要求(0. 学员进入学习项目详情即标记为已读)',
    `studyContent` mediumtext      COMMENT '学习内容',
    `filePath` varchar(512)      COMMENT '文件路径',
    `fileName` varchar(512)      COMMENT '文件名称',
    `remark` varchar(256)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
    PRIMARY KEY  (`id`)
    ,KEY `title` (`title`) USING BTREE
    ,KEY `projectType` (`projectType`) USING BTREE
    ,KEY `createUserId` (`createUserId`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='学习项目';
-- ----------------------------
-- 项目学习人员表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_project_study`;
CREATE TABLE mortals_xhx_project_study(
      `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键ID，主键，自增长',
      `projectId` bigint(20)      COMMENT '项目id',
      `projectType` tinyint(2)    DEFAULT '0'  COMMENT '项目类型(0.法律法规,1.业务知识,2.行业知识,3.通用知识)',
      `title` varchar(256) NOT NULL     COMMENT '项目名称',
      `userId` bigint(20)      COMMENT '用户id',
      `userName` varchar(256) NOT NULL     COMMENT '用户名称',
      `deptName` varchar(256) NOT NULL     COMMENT '所属部门',
      `studyStatus` tinyint(2) NOT NULL   DEFAULT '0'  COMMENT '学习状态(0.未学习,1.已学习)',
      `top` tinyint(2) NOT NULL   DEFAULT '0'  COMMENT '是否置顶(0.否，1.是)',
      `studyTime` datetime NOT NULL     COMMENT '学习时间',
      `remark` varchar(256)      COMMENT '备注',
      `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
      `createTime` datetime NOT NULL     COMMENT '创建时间',
      `updateUserId` bigint(20)      COMMENT '更新用户',
      `updateTime` datetime      COMMENT '更新时间',
      PRIMARY KEY  (`id`)
    ,KEY `title` (`title`) USING BTREE
    ,KEY `studyStatus` (`studyStatus`) USING BTREE
    ,KEY `createUserId` (`createUserId`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='项目学习人员';
-- ----------------------------
-- 学习公告表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_notice`;
CREATE TABLE mortals_xhx_notice(
   `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键ID，主键，自增长',
   `title` varchar(256) NOT NULL     COMMENT '标题',
   `noticeType` tinyint(2)    DEFAULT '0'  COMMENT '公告类型(0.通知,1.公告)',
   `pubDeptId` bigint(20)      COMMENT '发布部门id',
   `pubDeptName` varchar(512)      COMMENT '发布部门名称',
   `viewPersion` tinyint(2) NOT NULL   DEFAULT '0'  COMMENT '查看人员(0.全部学员，1.部分学员)',
   `top` tinyint(2) NOT NULL   DEFAULT '0'  COMMENT '是否置顶(0.否，1.是)',
   `readRequest` tinyint(2) NOT NULL   DEFAULT '0'  COMMENT '已读要求(0. 学员进入公告详情即标记为已读)',
   `noticeContent` mediumtext      COMMENT '公告内容',
   `filePath` varchar(512)      COMMENT '公告文件路径',
   `fileName` varchar(512)      COMMENT '公告文件名称',
   `remark` varchar(256)      COMMENT '备注',
   `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
   `createTime` datetime NOT NULL     COMMENT '创建时间',
   `updateUserId` bigint(20)      COMMENT '更新用户',
   `updateTime` datetime      COMMENT '更新时间',
   PRIMARY KEY  (`id`)
    ,KEY `title` (`title`) USING BTREE
    ,KEY `createUserId` (`createUserId`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='学习公告';
-- ----------------------------
-- 公告学习人员表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_notice_study`;
CREATE TABLE mortals_xhx_notice_study(
         `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键ID，主键，自增长',
         `noticeId` bigint(20)      COMMENT '公告id',
         `noticetType` tinyint(2)    DEFAULT '0'  COMMENT '公告类型(0.通知,1.公告,2.行业知识,3.通用知识)',
         `title` varchar(256) NOT NULL     COMMENT '公告标题',
         `userId` bigint(20)      COMMENT '用户id',
         `userName` varchar(256) NOT NULL     COMMENT '用户名称',
         `deptName` varchar(256) NOT NULL     COMMENT '所属部门',
         `noticeStatus` tinyint(2) NOT NULL   DEFAULT '0'  COMMENT '状态(0.未读,1.已读)',
         `top` tinyint(2) NOT NULL   DEFAULT '0'  COMMENT '是否置顶(0.否，1.是)',
         `viewTime` datetime NOT NULL     COMMENT '查看时间',
         `remark` varchar(256)      COMMENT '备注',
         `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
         `createTime` datetime NOT NULL     COMMENT '创建时间',
         `updateUserId` bigint(20)      COMMENT '更新用户',
         `updateTime` datetime      COMMENT '更新时间',
         PRIMARY KEY  (`id`)
    ,KEY `noticeStatus` (`noticeStatus`) USING BTREE
    ,KEY `createUserId` (`createUserId`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='公告学习人员';
-- ----------------------------
-- 部门信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_dept`;
CREATE TABLE mortals_xhx_dept(
     `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键ID，主键，自增长',
     `parentId` bigint(20)      COMMENT '父id',
     `ancestors` varchar(256) NOT NULL     COMMENT '祖级列表',
     `deptName` varchar(256) NOT NULL     COMMENT '部门名称',
     `deptStatus` tinyint(2) NOT NULL   DEFAULT '1'  COMMENT '部门状态(0.停用,1.启用)',
     `orderNum` int(4) NOT NULL   DEFAULT '0'  COMMENT '顺序',
     `remark` varchar(256)      COMMENT '备注',
     `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
     `createTime` datetime NOT NULL     COMMENT '创建时间',
     `updateUserId` bigint(20)      COMMENT '更新用户',
     `updateTime` datetime      COMMENT '更新时间',
     PRIMARY KEY  (`id`)
    ,KEY `deptStatus` (`deptStatus`) USING BTREE
    ,KEY `orderNum` (`orderNum`) USING BTREE
    ,KEY `createUserId` (`createUserId`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='部门信息';
-- ----------------------------
-- 学习统计表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_study_stat`;
CREATE TABLE mortals_xhx_study_stat(
   `id` bigint(20)   AUTO_INCREMENT   COMMENT 'ID',
   `siteId` bigint(20)      COMMENT '站点Id，来源基础服务平台',
   `projectTotalCount` int(9)    DEFAULT '0'  COMMENT '题目总数',
   `projectAddCount` int(9)    DEFAULT '0'  COMMENT '昨日新增项目数量',
   `studyPersonCount` int(9)    DEFAULT '0'  COMMENT '学习人数数量',
   `studyPersonRatio` double(6,2)    DEFAULT '0.00'  COMMENT '学习率',
    `unStudyPersonCount` int(9) NOT NULL   DEFAULT '0'  COMMENT '未学习人数数量',
    `unStudyPersonRatio` double(6,2) NOT NULL   DEFAULT '0.00'  COMMENT '未学习率',
    `pushTotalCount` int(9) NOT NULL   DEFAULT '0'  COMMENT '今日消息推送数量',
    `pushAddCount` int(9) NOT NULL   DEFAULT '0'  COMMENT '昨日新增减少数量',
    `year` int(9) NOT NULL     COMMENT '年',
    `month` int(9) NOT NULL     COMMENT '月',
    `day` int(9) NOT NULL     COMMENT '日',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
,KEY `siteId` (`siteId`) USING BTREE
,KEY `projectTotalCount` (`projectTotalCount`) USING BTREE
,KEY `projectAddCount` (`projectAddCount`) USING BTREE
,KEY `unStudyPersonCount` (`unStudyPersonCount`) USING BTREE
,KEY `unStudyPersonRatio` (`unStudyPersonRatio`) USING BTREE
,KEY `pushTotalCount` (`pushTotalCount`) USING BTREE
,KEY `pushAddCount` (`pushAddCount`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='学习统计';
